@@ -1,4 +1,4 @@
-// Copyright 2018-2020 Cargill Incorporated
+// Copyright 2018-2021 Cargill Incorporated
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -15,4 +15,6 @@
 //! Defines a basic API to register and authenticate a User using a username and a password.
 //! Not recommended for use in production.
 
+#[cfg(feature = "rest-api")]
+pub mod rest_api;
 pub mod store;
