@@ -1,4 +1,4 @@
-// Copyright 2018-2020 Cargill Incorporated
+// Copyright 2018-2021 Cargill Incorporated
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -41,7 +41,7 @@ impl std::fmt::Display for FrameError {
                 HEADER_LENGTH, n
             ),
             FrameError::UnsupportedVersion => f.write_str("Unsupported frame version"),
-            FrameError::HandshakeFailure(msg) => f.write_str(msg),
+            FrameError::HandshakeFailure(msg) => f.write_str(&msg),
         }
     }
 }
